@@ -1,21 +1,7 @@
 # Copyright 2015-2016, Tresys Technology, LLC
 # Copyright 2018, Chris PeBenito <pebenito@ieee.org>
 #
-# This file is part of SETools.
-#
-# SETools is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation, either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# SETools is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with SETools.  If not, see
-# <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: LGPL-2.1-only
 #
 from collections import defaultdict
 
@@ -43,8 +29,7 @@ def conditional_wrapper_factory(cond: Conditional) -> "ConditionalWrapper":
         return a
 
 
-# Pylint bug: https://github.com/PyCQA/pylint/issues/2822
-class ConditionalWrapper(Wrapper[Conditional]):  # pylint: disable=unsubscriptable-object
+class ConditionalWrapper(Wrapper[Conditional]):
 
     """Wrap conditional policy expressions to allow comparisons by truth table."""
 
