@@ -1,20 +1,6 @@
 # Copyright 2016, Tresys Technology, LLC
 #
-# This file is part of SETools.
-#
-# SETools is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation, either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# SETools is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with SETools.  If not, see
-# <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: LGPL-2.1-only
 #
 from typing import NamedTuple
 
@@ -74,8 +60,7 @@ class GenfsconsDifference(Difference):
         self.modified_genfscons = None
 
 
-# Pylint bug: https://github.com/PyCQA/pylint/issues/2822
-class GenfsconWrapper(Wrapper[Genfscon]):  # pylint: disable=unsubscriptable-object
+class GenfsconWrapper(Wrapper[Genfscon]):
 
     """Wrap genfscon rules to allow set operations."""
 
