@@ -1,40 +1,38 @@
 # Copyright 2014-2015, Tresys Technology, LLC
 #
-# This file is part of SETools.
-#
-# SETools is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation, either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# SETools is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with SETools.  If not, see
-# <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: LGPL-2.1-only
 #
 import itertools
 import logging
 from contextlib import suppress
+from typing import cast, Iterable, List, Mapping, Optional, Union
 
-import networkx as nx
-from networkx.exception import NetworkXError, NetworkXNoPath, NodeNotFound
+try:
+    import networkx as nx
+    from networkx.exception import NetworkXError, NetworkXNoPath, NodeNotFound
+except ImportError:
+    logging.getLogger(__name__).debug("NetworkX failed to import.")
 
 from .descriptors import EdgeAttrIntMax, EdgeAttrList
-from .exception import RuleNotConditional
-from .policyrep import TERuletype
+from .permmap import PermissionMap
+from .policyrep import AVRule, SELinuxPolicy, TERuletype, Type
 
 __all__ = ['InfoFlowAnalysis']
 
+InfoFlowPath = Iterable['InfoFlowStep']
+
 
 class InfoFlowAnalysis:
 
     """Information flow analysis."""
 
-    def __init__(self, policy, perm_map, min_weight=1, exclude=None, booleans=None):
+    _exclude: List[Type]
+    _min_weight: int
+    _perm_map: PermissionMap
+
+    def __init__(self, policy: SELinuxPolicy, perm_map: PermissionMap, min_weight: int = 1,
+                 exclude: Optional[Iterable[Union[Type, str]]] = None,
+                 booleans: Optional[Mapping[str, bool]] = None) -> None:
         """
         Parameters:
         policy      The policy to analyze.
@@ -54,20 +52,26 @@ class InfoFlowAnalysis:
 
         self.min_weight = min_weight
         self.perm_map = perm_map
-        self.exclude = exclude
+        self.exclude = exclude  # type: ignore # https://github.com/python/mypy/issues/220
         self.booleans = booleans
         self.rebuildgraph = True
         self.rebuildsubgraph = True
 
-        self.G = nx.DiGraph()
-        self.subG = None
+        try:
+            self.G = nx.DiGraph()
+            self.subG = self.G.copy()
+        except NameError:
+            self.log.critical("NetworkX is not available.  This is "
+                              "requried for Information Flow Analysis.")
+            self.log.critical("This is typically in the python3-networkx package.")
+            raise
 
     @property
-    def min_weight(self):
+    def min_weight(self) -> int:
         return self._min_weight
 
     @min_weight.setter
-    def min_weight(self, weight):
+    def min_weight(self, weight: int) -> None:
         if not 1 <= weight <= 10:
             raise ValueError(
                 "Min information flow weight must be an integer 1-10.")
@@ -76,29 +80,29 @@ class InfoFlowAnalysis:
         self.rebuildsubgraph = True
 
     @property
-    def perm_map(self):
+    def perm_map(self) -> PermissionMap:
         return self._perm_map
 
     @perm_map.setter
-    def perm_map(self, perm_map):
+    def perm_map(self, perm_map: PermissionMap) -> None:
         self._perm_map = perm_map
         self.rebuildgraph = True
         self.rebuildsubgraph = True
 
     @property
-    def exclude(self):
+    def exclude(self) -> List[Type]:
         return self._exclude
 
     @exclude.setter
-    def exclude(self, types):
+    def exclude(self, types: Optional[Iterable[Union[Type, str]]]) -> None:
         if types:
-            self._exclude = [self.policy.lookup_type(t) for t in types]
+            self._exclude: List[Type] = [self.policy.lookup_type(t) for t in types]
         else:
             self._exclude = []
 
         self.rebuildsubgraph = True
 
-    def shortest_path(self, source, target):
+    def shortest_path(self, source: Type, target: Type) -> Iterable[InfoFlowPath]:
         """
         Generator which yields one shortest path between the source
         and target types (there may be more).
@@ -129,9 +133,11 @@ class InfoFlowAnalysis:
             # excluded or disconnected due to min weight
             # NetworkXNoPath: no paths or the target type is
             # not in the graph
-            yield self.__generate_steps(nx.shortest_path(self.subG, s, t))
+            # pylint: disable=unexpected-keyword-arg, no-value-for-parameter
+            yield self.__generate_steps(nx.shortest_path(self.subG, source=s, target=t))
 
-    def all_paths(self, source, target, maxlen=2):
+    def all_paths(self, source: Union[Type, str], target: Union[Type, str], maxlen: int = 2) \
+            -> Iterable[InfoFlowPath]:
         """
         Generator which yields all paths between the source and target
         up to the specified maximum path length.  This algorithm
@@ -171,7 +177,8 @@ class InfoFlowAnalysis:
             for path in nx.all_simple_paths(self.subG, s, t, maxlen):
                 yield self.__generate_steps(path)
 
-    def all_shortest_paths(self, source, target):
+    def all_shortest_paths(self, source: Union[Type, str], target: Union[Type, str]) \
+            -> Iterable[InfoFlowPath]:
         """
         Generator which yields all shortest paths between the source
         and target types.
@@ -205,7 +212,7 @@ class InfoFlowAnalysis:
             for path in nx.all_shortest_paths(self.subG, s, t):
                 yield self.__generate_steps(path)
 
-    def infoflows(self, type_, out=True):
+    def infoflows(self, type_: Union[Type, str], out: bool = True) -> Iterable['InfoFlowStep']:
         """
         Generator which yields all information flows in/out of a
         specified source type.
@@ -242,9 +249,9 @@ class InfoFlowAnalysis:
                 flows = self.subG.in_edges(s)
 
             for source, target in flows:
-                yield Edge(self.subG, source, target)
+                yield InfoFlowStep(self.subG, source, target)
 
-    def get_stats(self):  # pragma: no cover
+    def get_stats(self) -> str:  # pragma: no cover
         """
         Get the information flow graph statistics.
 
@@ -253,13 +260,14 @@ class InfoFlowAnalysis:
         if self.rebuildgraph:
             self._build_graph()
 
-        return nx.info(self.G)
+        return f"Graph nodes: {nx.number_of_nodes(self.G)}\n" \
+               f"Graph edges: {nx.number_of_edges(self.G)}"
 
     #
     # Internal functions follow
     #
 
-    def __generate_steps(self, path):
+    def __generate_steps(self, path: List[Type]) -> InfoFlowPath:
         """
         Generator which returns the source, target, and associated rules
         for each information flow step.
@@ -274,7 +282,7 @@ class InfoFlowAnalysis:
         rules   The list of rules creating this information flow step.
         """
         for s in range(1, len(path)):
-            yield Edge(self.subG, path[s - 1], path[s])
+            yield InfoFlowStep(self.subG, path[s - 1], path[s])
 
     #
     #
@@ -291,7 +299,7 @@ class InfoFlowAnalysis:
     #    minimum weight. This subgraph is rebuilt only if the main graph
     #    is rebuilt or the minimum weight or excluded types change.
 
-    def _build_graph(self):
+    def _build_graph(self) -> None:
         self.G.clear()
         self.G.name = "Information flow graph for {0}.".format(self.policy)
 
@@ -303,19 +311,19 @@ class InfoFlowAnalysis:
             if rule.ruletype != TERuletype.allow:
                 continue
 
-            (rweight, wweight) = self.perm_map.rule_weight(rule)
+            (rweight, wweight) = self.perm_map.rule_weight(cast(AVRule, rule))
 
             for s, t in itertools.product(rule.source.expand(), rule.target.expand()):
                 # only add flows if they actually flow
                 # in or out of the source type type
                 if s != t:
                     if wweight:
-                        edge = Edge(self.G, s, t, create=True)
+                        edge = InfoFlowStep(self.G, s, t, create=True)
                         edge.rules.append(rule)
                         edge.weight = wweight
 
                     if rweight:
-                        edge = Edge(self.G, t, s, create=True)
+                        edge = InfoFlowStep(self.G, t, s, create=True)
                         edge.rules.append(rule)
                         edge.weight = rweight
 
@@ -326,7 +334,7 @@ class InfoFlowAnalysis:
             nx.number_of_nodes(self.G),
             nx.number_of_edges(self.G)))
 
-    def _build_subgraph(self):
+    def _build_subgraph(self) -> None:
         if self.rebuildgraph:
             self._build_graph()
 
@@ -346,7 +354,7 @@ class InfoFlowAnalysis:
         if self.min_weight > 1:
             delete_list = []
             for s, t in self.subG.edges():
-                edge = Edge(self.subG, s, t)
+                edge = InfoFlowStep(self.subG, s, t)
                 if edge.weight < self.min_weight:
                     delete_list.append(edge)
 
@@ -355,7 +363,7 @@ class InfoFlowAnalysis:
         if self.booleans is not None:
             delete_list = []
             for s, t in self.subG.edges():
-                edge = Edge(self.subG, s, t)
+                edge = InfoFlowStep(self.subG, s, t)
 
                 # collect disabled rules
                 rule_list = []
@@ -364,7 +372,7 @@ class InfoFlowAnalysis:
                     if not rule.enabled(**self.booleans):
                         rule_list.append(rule)
 
-                deleted_rules = []
+                deleted_rules: List[AVRule] = []
                 for rule in rule_list:
                     if rule not in deleted_rules:
                         edge.rules.remove(rule)
@@ -382,7 +390,7 @@ class InfoFlowAnalysis:
             nx.number_of_edges(self.subG)))
 
 
-class Edge:
+class InfoFlowStep:
 
     """
     A graph edge.  Also used for returning information flow steps.
@@ -406,7 +414,7 @@ class Edge:
     # (see below add_edge() call)
     weight = EdgeAttrIntMax('capacity')
 
-    def __init__(self, graph, source, target, create=False):
+    def __init__(self, graph, source: Type, target: Type, create: bool = False) -> None:
         self.G = graph
         self.source = source
         self.target = target
@@ -417,7 +425,7 @@ class Edge:
                 self.rules = None
                 self.weight = None
             else:
-                raise ValueError("Edge does not exist in graph")
+                raise ValueError("InfoFlowStep does not exist in graph")
 
     def __getitem__(self, key):
         # This is implemented so this object can be used in NetworkX
