@@ -1,26 +1,13 @@
 # Copyright 2014-2015, Tresys Technology, LLC
 #
-# This file is part of SETools.
-#
-# SETools is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation, either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# SETools is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with SETools.  If not, see
-# <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: LGPL-2.1-only
 #
 import logging
+from typing import Iterable
 
 from .descriptors import CriteriaDescriptor, CriteriaSetDescriptor
 from .mixins import MatchObjClass
-from .policyrep import MLSRuletype
+from .policyrep import MLSRule, MLSRuletype
 from .query import PolicyQuery
 from .util import match_indirect_regex, match_range
 
@@ -48,24 +35,24 @@ class MLSRuleQuery(MatchObjClass, PolicyQuery):
 
     ruletype = CriteriaSetDescriptor(enum_class=MLSRuletype)
     source = CriteriaDescriptor("source_regex", "lookup_type_or_attr")
-    source_regex = False
-    source_indirect = True
+    source_regex: bool = False
+    source_indirect: bool = True
     target = CriteriaDescriptor("target_regex", "lookup_type_or_attr")
-    target_regex = False
-    target_indirect = True
+    target_regex: bool = False
+    target_indirect: bool = True
     tclass = CriteriaSetDescriptor("tclass_regex", "lookup_class")
-    tclass_regex = False
+    tclass_regex: bool = False
     default = CriteriaDescriptor(lookup_function="lookup_range")
-    default_overlap = False
-    default_subset = False
-    default_superset = False
-    default_proper = False
+    default_overlap: bool = False
+    default_subset: bool = False
+    default_superset: bool = False
+    default_proper: bool = False
 
-    def __init__(self, policy, **kwargs):
+    def __init__(self, policy, **kwargs) -> None:
         super(MLSRuleQuery, self).__init__(policy, **kwargs)
         self.log = logging.getLogger(__name__)
 
-    def results(self):
+    def results(self) -> Iterable[MLSRule]:
         """Generator which yields all matching MLS rules."""
         self.log.info("Generating MLS rule results from {0.policy}".format(self))
         self.log.debug("Ruletypes: {0.ruletype}".format(self))
