@@ -1,23 +1,11 @@
 # Copyright 2016, Tresys Technology, LLC
 #
-# This file is part of SETools.
+# SPDX-License-Identifier: LGPL-2.1-only
 #
-# SETools is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation, either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# SETools is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with SETools.  If not, see
-# <http://www.gnu.org/licenses/>.
 #
 
 import logging
+from contextlib import suppress
 
 from PyQt5.QtCore import Qt, QSortFilterProxyModel, QStringListModel, QThread
 from PyQt5.QtGui import QPalette, QTextCursor
@@ -27,7 +15,7 @@ from setools import SensitivityQuery
 from ..logtosignal import LogHandlerToSignal
 from ..models import SEToolsListModel, invert_list_selection
 from ..mlsmodel import MLSComponentTableModel, sensitivity_detail
-from .analysistab import AnalysisTab
+from .analysistab import AnalysisSection, AnalysisTab
 from .exception import TabFieldError
 from .queryupdater import QueryResultsUpdater
 from .workspace import load_checkboxes, load_lineedits, load_textedits, \
@@ -38,6 +26,10 @@ class SensitivityQueryTab(AnalysisTab):
 
     """Sensitivity browser and query tab."""
 
+    section = AnalysisSection.Components
+    tab_title = "MLS Sensitivities"
+    mlsonly = True
+
     def __init__(self, parent, policy, perm_map):
         super(SensitivityQueryTab, self).__init__(parent)
         self.log = logging.getLogger(__name__)
@@ -46,8 +38,10 @@ class SensitivityQueryTab(AnalysisTab):
         self.setupUi()
 
     def __del__(self):
-        self.thread.quit()
-        self.thread.wait(5000)
+        with suppress(RuntimeError):
+            self.thread.quit()
+            self.thread.wait(5000)
+
         logging.getLogger("setools.sensitivityquery").removeHandler(self.handler)
 
     def setupUi(self):
@@ -63,13 +57,13 @@ class SensitivityQueryTab(AnalysisTab):
         self.sort_proxy = QSortFilterProxyModel(self)
         self.sort_proxy.setSourceModel(self.table_results_model)
         self.table_results.setModel(self.sort_proxy)
-        self.table_results.sortByColumn(0, Qt.AscendingOrder)
+        self.table_results.sortByColumn(0, Qt.SortOrder.AscendingOrder)
 
         # setup indications of errors on level/range
         self.errors = set()
         self.orig_palette = self.name.palette()
         self.error_palette = self.name.palette()
-        self.error_palette.setColor(QPalette.Base, Qt.red)
+        self.error_palette.setColor(QPalette.ColorRole.Base, Qt.GlobalColor.red)
         self.clear_name_error()
 
         # set up processing thread
@@ -111,7 +105,7 @@ class SensitivityQueryTab(AnalysisTab):
     def get_detail(self):
         # .ui is set for single item selection.
         index = self.sens.selectedIndexes()[0]
-        item = self.sensitivity_model.data(index, Qt.UserRole)
+        item = self.sensitivity_model.data(index, Qt.ItemDataRole.UserRole)
 
         self.log.debug("Generating detail window for {0}".format(item))
         sensitivity_detail(self, item)
@@ -192,6 +186,6 @@ class SensitivityQueryTab(AnalysisTab):
         if not self.busy.wasCanceled():
             self.busy.setLabelText("Moving the raw result to top; GUI may be unresponsive")
             self.busy.repaint()
-            self.raw_results.moveCursor(QTextCursor.Start)
+            self.raw_results.moveCursor(QTextCursor.MoveOperation.Start)
 
         self.busy.reset()
