@@ -1,33 +1,21 @@
 # Copyright 2015-2016, Tresys Technology, LLC
 #
-# This file is part of SETools.
+# SPDX-License-Identifier: LGPL-2.1-only
 #
-# SETools is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation, either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# SETools is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with SETools.  If not, see
-# <http://www.gnu.org/licenses/>.
 #
 
 import logging
+from contextlib import suppress
 
 from PyQt5.QtCore import Qt, QSortFilterProxyModel, QStringListModel, QThread
 from PyQt5.QtGui import QPalette, QTextCursor
 from PyQt5.QtWidgets import QCompleter, QHeaderView, QMessageBox, QProgressDialog
-from setools import TERuleQuery
+from setools import TERuleQuery, xperm_str_to_tuple_ranges
 
 from ..logtosignal import LogHandlerToSignal
 from ..models import PermListModel, SEToolsListModel, invert_list_selection
 from ..terulemodel import TERuleTableModel
-from .analysistab import AnalysisTab
+from .analysistab import AnalysisSection, AnalysisTab
 from .exception import TabFieldError
 from .queryupdater import QueryResultsUpdater
 from .workspace import load_checkboxes, load_lineedits, load_listviews, load_textedits, \
@@ -38,6 +26,10 @@ class TERuleQueryTab(AnalysisTab):
 
     """A Type Enforcement rule query."""
 
+    section = AnalysisSection.Rules
+    tab_title = "TE Rules"
+    mlsonly = False
+
     def __init__(self, parent, policy, perm_map):
         super(TERuleQueryTab, self).__init__(parent)
         self.log = logging.getLogger(__name__)
@@ -46,8 +38,10 @@ class TERuleQueryTab(AnalysisTab):
         self.setupUi()
 
     def __del__(self):
-        self.thread.quit()
-        self.thread.wait(5000)
+        with suppress(RuntimeError):
+            self.thread.quit()
+            self.thread.wait(5000)
+
         logging.getLogger("setools.terulequery").removeHandler(self.handler)
 
     def setupUi(self):
@@ -75,7 +69,7 @@ class TERuleQueryTab(AnalysisTab):
         self.errors = set()
         self.orig_palette = self.source.palette()
         self.error_palette = self.source.palette()
-        self.error_palette.setColor(QPalette.Base, Qt.red)
+        self.error_palette.setColor(QPalette.ColorRole.Base, Qt.GlobalColor.red)
         self.clear_source_error()
         self.clear_target_error()
         self.clear_default_error()
@@ -100,7 +94,7 @@ class TERuleQueryTab(AnalysisTab):
         self.sort_proxy = QSortFilterProxyModel(self)
         self.sort_proxy.setSourceModel(self.table_results_model)
         self.table_results.setModel(self.sort_proxy)
-        self.table_results.sortByColumn(0, Qt.AscendingOrder)
+        self.table_results.sortByColumn(0, Qt.SortOrder.AscendingOrder)
 
         # set up processing thread
         self.thread = QThread()
@@ -227,7 +221,7 @@ class TERuleQueryTab(AnalysisTab):
     def set_tclass(self):
         selected_classes = []
         for index in self.tclass.selectionModel().selectedIndexes():
-            selected_classes.append(self.class_model.data(index, Qt.UserRole))
+            selected_classes.append(self.class_model.data(index, Qt.ItemDataRole.UserRole))
 
         self.query.tclass = selected_classes
         self.perms_model.set_classes(selected_classes)
@@ -242,7 +236,7 @@ class TERuleQueryTab(AnalysisTab):
     def set_perms(self):
         selected_perms = []
         for index in self.perms.selectionModel().selectedIndexes():
-            selected_perms.append(self.perms_model.data(index, Qt.UserRole))
+            selected_perms.append(self.perms_model.data(index, Qt.ItemDataRole.UserRole))
 
         self.query.perms = selected_perms
 
@@ -267,22 +261,11 @@ class TERuleQueryTab(AnalysisTab):
                                   "Comma-separated permissions or ranges of permissions.")
 
     def set_xperm(self):
-        xperms = []
         try:
             text = self.xperms.text()
 
             if text:
-                for item in self.xperms.text().split(","):
-                    rng = item.split("-")
-                    if len(rng) == 2:
-                        xperms.append((int(rng[0], base=16), int(rng[1], base=16)))
-                    elif len(rng) == 1:
-                        xperms.append((int(rng[0], base=16), int(rng[0], base=16)))
-                    else:
-                        raise ValueError("Enter an extended permission or extended permission "
-                                         "range, e.g. 0x5411 or 0x8800-0x88ff.")
-
-                self.query.xperms = xperms
+                self.query.xperms = xperm_str_to_tuple_ranges(text)
             else:
                 self.query.xperms = None
 
@@ -319,7 +302,7 @@ class TERuleQueryTab(AnalysisTab):
     def set_bools(self):
         selected_bools = []
         for index in self.bool_criteria.selectionModel().selectedIndexes():
-            selected_bools.append(self.bool_model.data(index, Qt.UserRole))
+            selected_bools.append(self.bool_model.data(index, Qt.ItemDataRole.UserRole))
 
         self.query.boolean = selected_bools
 
@@ -424,9 +407,9 @@ class TERuleQueryTab(AnalysisTab):
             reply = QMessageBox.question(
                 self, "Continue?",
                 "This is a broad query, estimated to return {0} results.  Continue?".
-                format(max_results), QMessageBox.Yes | QMessageBox.No)
+                format(max_results), QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.No)
 
-            if reply == QMessageBox.No:
+            if reply == QMessageBox.StandardButton.No:
                 return
 
         # start processing
@@ -457,6 +440,6 @@ class TERuleQueryTab(AnalysisTab):
         if not self.busy.wasCanceled():
             self.busy.setLabelText("Moving the raw result to top; GUI may be unresponsive")
             self.busy.repaint()
-            self.raw_results.moveCursor(QTextCursor.Start)
+            self.raw_results.moveCursor(QTextCursor.MoveOperation.Start)
 
         self.busy.reset()
